@@ -25,11 +25,12 @@ import datetime
 import shutil
 
 import bigml.api
-import bigmler.utils as u
-import bigmler.processing.args as a
 
 from bigml.api import get_resource_type
 
+import bigmler.utils as u
+import bigmler.processing.args as a
+
 from bigmler.defaults import DEFAULTS_FILE
 from bigmler.command import get_stored_command, command_handling
 from bigmler.dispatcher import SESSIONS_LOG, clear_log_files
@@ -65,6 +66,8 @@ STATUS_CODES = {
 
 GROUP_RESOURCES = ["project", "execution"]
 COMPOSED_RESOURCES = ["cluster", "ensemble", "fusion", "composites", "optiml"]
+SYNCHRONOUS_RESOURCES = ["project", "prediction", "centroid", "anomalyscore",
+    "topicdistribution", "associationset", "forecast", "projection"]
 TRASH_BIN = "Trash bin"
 
 
@@ -103,10 +106,12 @@ def retrieve_resources(directory):
         for root, _, files in os.walk(directory):
             for resources_file in files:
                 if resources_file in RESOURCES_LOG_FILES:
-                    for line in open(os.path.join(root, resources_file)):
-                        resource_id = bigml.api.get_resource_id(line.strip())
-                        if resource_id is not None:
-                            log_ids.append(resource_id)
+                    with open(os.path.join(root, resources_file)) as reader:
+                        for line in reader:
+                            resource_id = bigml.api.get_resource_id(
+                                line.strip())
+                            if resource_id is not None:
+                                log_ids.append(resource_id)
     return list(set(log_ids))
 
 
@@ -150,7 +155,7 @@ def get_delete_list(args, api, query_list):
     delete_list = []
 
     if resource_selectors:
-        for selector, api_call, filter_linked in resource_selectors:
+        for res_type, selector, api_call, filter_linked in resource_selectors:
             query_value = args.all_tag
             type_query_list = query_list[:]
             if args.all_tag or selector:
@@ -161,6 +166,8 @@ def get_delete_list(args, api, query_list):
                 type_query_list.append(filter_linked)
             if type_query_list:
                 status_code = STATUS_CODES[args.status]
+                if res_type in SYNCHRONOUS_RESOURCES:
+                    status_code = None
                 delete_list.extend(u.list_ids(api_call,
                                               ";".join(type_query_list),
                                               status_code=status_code))
@@ -270,6 +277,8 @@ def filtered_selectors(args, api):
          api.list_batch_anomaly_scores, None),
         ("sample", args.sample_tag, api.list_samples, None),
         ("association", args.association_tag, api.list_associations, None),
+        ("associationset", args.association_set_tag, api.list_association_sets,
+         None),
         ("logisticregression", args.logistic_regression_tag,
          api.list_logistic_regressions, None),
         ("topicmodel", args.topic_model_tag,
@@ -284,7 +293,8 @@ def filtered_selectors(args, api):
         ("fusion", args.fusion_tag, api.list_fusions, None),
         ("pca", args.pca_tag, api.list_pcas, None),
         ("projection", args.projection_tag, api.list_projections, None),
-        ("batch_projection", args.batch_projections_tag, api.list_batch_projections, None),
+        ("batchprojection", args.batch_projections_tag,
+         api.list_batch_projections, None),
         ("linearregression", args.linear_regression_tag,
          api.list_linear_regressions, None),
         ("externalconnector", args.external_connector_tag,
@@ -292,20 +302,21 @@ def filtered_selectors(args, api):
         ("script", args.script_tag, api.list_scripts, None),
         ("library", args.library_tag, api.list_libraries, None)]
 
-    if args.all_tag is None and any([resource[1] is not None for resource in
-                                     resource_selectors]):
+    if args.all_tag is None and any(resource[1] is not None for resource in
+                                     resource_selectors):
         # choose which selectors by tag are used and keep only these
         # selected by resource_tag
         resource_selectors = [resource for resource in resource_selectors if
                               resource[1] is not None]
 
     # selected by resource_types (on top of the tag selectors)
-    selectors = [resource[1:] for resource in resource_selectors
+    selectors = [resource for resource in resource_selectors
                  if args.resource_types_ is None or
                  resource[0] in args.resource_types_]
     return selectors
 
 
+#pylint: disable=locally-disabled,dangerous-default-value
 def delete_dispatcher(args=sys.argv[1:]):
     """Parses command line and calls the different processing functions
 
@@ -417,9 +428,9 @@ def delete_resources(command_args, api, deleted_list=None):
         if resource_id not in deleted_list]
     # if there are projects or executions, delete them first
     bulk_deletion = not command_args.bin and not command_args.dry_run and \
-        any([resource_id.startswith("project/") or \
+        any(resource_id.startswith("project/") or \
         (not command_args.execution_only and \
-         resource_id.startswith("execution/")) for resource_id in delete_list])
+         resource_id.startswith("execution/")) for resource_id in delete_list)
     aprox = "*" if bulk_deletion else ""
     # if bulk_deletion, keep only the project and executions resources in
     # the deletion list
