@@ -23,7 +23,6 @@ import sys
 import os
 import datetime
 import json
-import tempfile
 
 from io import StringIO
 
@@ -1146,8 +1145,8 @@ def transform_args(command_args, flags, api):
                 and not command_args.method in list(COMBINATION_WEIGHTS.keys())):
             command_args.method = 0
         else:
-            combiner_methods = dict(
-                [[value, key] for key, value in list(COMBINER_MAP.items())])
+            combiner_methods = {
+                value: key for key, value in list(COMBINER_MAP.items())}
             combiner_methods[COMBINATION_LABEL] = COMBINATION
             command_args.method = combiner_methods.get(command_args.method, 0)
     except AttributeError:
